@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.54 2005/12/26 13:57:46 joern Exp $
+# $Id: Config.pm,v 1.55 2006/01/03 19:36:52 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -107,9 +107,9 @@ my %CONFIG_PARAMETER = (
 	play_dvd_command => {
 		label => __"DVD player command",
 		type  => 'string',
-		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %(%m+1) -dvd-device %d>',
+		value => 'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
 		presets => [
-			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %(%m+1) -dvd-device %d>',
+			'mplayer <dvd://%t -aid %(%a+%b) -chapter %c -dvdangle %m -dvd-device %d>',
 			'xine -a %a -p <dvd://%d/%t.%c>',
 		],
 		rules => "executable-command",
@@ -692,7 +692,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.54 2005/12/26 13:57:46 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.55 2006/01/03 19:36:52 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
