@@ -1,4 +1,4 @@
-# $Id: BurnCD.pm,v 1.6 2003/02/05 22:17:25 joern Exp $
+# $Id: BurnCD.pm,v 1.9 2005/12/26 13:57:47 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,8 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::BurnCD;
+use Locale::TextDomain qw (video.dvdrip);
+use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Job;
 
@@ -21,6 +23,9 @@ sub set_max_size		{ shift->{max_size}		= $_[1]	}
 sub test_mode			{ shift->{test_mode}			}
 sub set_test_mode		{ shift->{test_mode}		= $_[1]	}
 
+sub erase_cdrw			{ shift->{erase_cdrw}			}
+sub set_erase_cdrw		{ shift->{erase_cdrw}		= $_[1]	}
+
 sub wait_for_start		{ shift->{wait_for_start}		}
 sub set_wait_for_start		{ shift->{wait_for_start}	= $_[1]	}
 
@@ -38,21 +43,23 @@ sub info {
 	my $test_mode = "";
 	$test_mode = "(simulation) " if $self->test_mode;
 
+	my $what = $self->erase_cdrw ? __"Erase CD-RW" : __"Burn CD";
+
 	my $info;
 	if ( $self->wait_for_start == -1 ) {
-		$info = "Burn CD $test_mode";
+		$info = "$what $test_mode";
 
 	} elsif ( $self->wait_for_start == -2 ) {
-		$info = "Burn CD $test_mode- waiting 10 seconds";
+		$info = __x("{what} {test_mode}- waiting 10 seconds", what => $what, test_mode => $test_mode);
 
 	} elsif ( $self->wait_for_start ) {
-		$info = "Burn CD $test_mode- starting in ".$self->wait_for_start. " seconds";
+		$info = __x("{what} {test_mode}- starting in {wait} seconds", what => $what, test_mode => $test_mode, wait => $self->wait_for_start);
 
 	} elsif ( $self->fixating ) {
-		$info = "Fixating CD $test_mode";
+		$info = __x("Fixating CD {test_mode}", test_mode => $test_mode);
 
 	} else {
-		$info = "Burn CD $test_mode";
+		$info = "$what $test_mode";
 	}
 
 	return $info;
@@ -75,7 +82,11 @@ sub init {
 sub command {
 	my $self = shift;
 
-	return $self->title->get_burn_command;
+	if ( $self->erase_cdrw ) {
+		return $self->title->get_erase_cdrw_command;
+	} else {
+		return $self->title->get_burn_command;
+	}
 }
 
 sub parse_output {
@@ -87,10 +98,10 @@ sub parse_output {
 
 	if ( $line =~ m!(\d+)\s+seconds.! ) {
 		if ( $self->title->burn_cd_type ne 'iso' ) {
-#print "DAO WAITING 10 SECONDS\n";
+#print "DAO WARTE 10 SEKUNDEN\n";
 			$self->set_wait_for_start (-2);
 		} else {
-#print "CDR WAITING $1 SECONDS\n";
+#print "CDR WARTE $1 SEKUNDEN\n";
 			$self->set_wait_for_start ( $1 );
 		}
 		if ( $1 == 0 ) {
@@ -102,18 +113,18 @@ sub parse_output {
 	if ( ( $self->title->burning_an_image or 
 	       ( ( not $self->title->burning_an_image ) and $self->title->config('burn_estimate_size') ) ) and
 	     $line =~ m!(\d+)\s+of\s+(\d+)\s+MB!i ) {
-#print "IMAGE: PROGRESS: $1 of $2\n";
+#print "ABBILD: FORTSCHRITT: $1 of $2\n";
 		$self->set_progress_cnt ( int(10000*$1/$2) );
 		$self->set_fixating(1) if $1 >= $2;
-#print "IMAGE: fixating" if $1 >= $2;
+#print "ABBILD: fixiere" if $1 >= $2;
 		$self->set_wait_for_start ( 0 );
 
 	} elsif ( ( not $self->title->burning_an_image ) and ( not $self->title->config('burn_estimate_size') ) and 
 	          $line =~ m!:\s+(\d+)\s+MB! ) {
 		$self->set_progress_cnt ( int(10000*$1/$self->max_size) );
-#print "FLY: PROGRESS: $1 of ".$self->max_size,"\n";
+#print "FLY: FORTSCHRITT: $1 of ".$self->max_size,"\n";
 		$self->set_fixating(1) if $1 >= $self->max_size;
-#print "FLY: fixating" if $1 >= $self->max_size;
+#print "FLY: fixiere" if $1 >= $self->max_size;
 		$self->set_wait_for_start ( 0 );
 	}
 
