@@ -1,4 +1,4 @@
-# $Id: Probe.pm,v 1.3 2003/01/28 20:19:57 joern Exp $
+# $Id: Probe.pm,v 1.6 2005/12/26 13:57:47 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,8 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::Probe;
+use Locale::TextDomain qw (video.dvdrip);
+use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Job;
 
@@ -22,7 +24,8 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info = "Probing - title #".$self->title->nr;
+	my $info = __"Probing";
+	$info .= " - ".__x("title #{title}", title => $self->title->nr);
 
 	return $info;
 }
@@ -34,6 +37,7 @@ sub init {
 	$self->set_progress_cnt($self->title->nr);
 	$self->set_progress_show_fps(0);
 	$self->set_progress_show_elapsed(0);
+	$self->set_progress_show_percent(1);
 
 	1;
 }
