@@ -1,13 +1,16 @@
-# $Id: Preset.pm,v 1.4 2002/03/24 22:54:09 joern Exp $
+# $Id: Preset.pm,v 1.8 2005/12/26 13:57:46 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
+# All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Preset;
+use Locale::TextDomain qw (video.dvdrip);
+use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Base;
 
